==> db-migrate-0.11.1.tgz: package/README.md <==
[![Build Status](https://travis-ci.org/db-migrate/node-db-migrate.svg?branch=master)](https://travis-ci.org/db-migrate/node-db-migrate)
[![Dependency Status](https://david-dm.org/db-migrate/node-db-migrate.svg)](https://david-dm.org/db-migrate/node-db-migrate)
[![devDependency Status](https://david-dm.org/db-migrate/node-db-migrate/dev-status.svg)](https://david-dm.org/db-migrate/node-db-migrate#info=devDependencies)
[![Documentation Status](https://readthedocs.org/projects/db-migrate/badge/?version=latest)](https://readthedocs.org/projects/db-migrate/?badge=latest)

# db-migrate

[![Join the chat at https://gitter.im/db-migrate/node-db-migrate](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/db-migrate/node-db-migrate?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

[![NPM](https://nodei.co/npm/db-migrate.png?downloads=true&downloadRank=true)](https://nodei.co/npm/db-migrate/)

Database migration framework for node.js

## Installation

    $ npm install -g db-migrate

DB-Migrate is now available to you via:

    $ db-migrate

### As local module

Want to use db-migrate as local module?

    $ npm install db-migrate

DB-Migrate is now available to you via:

    $ node node_modules/db-migrate/bin/db-migrate

## Officially Supported Databases

* Mysql (https://github.com/felixge/node-mysql)
https://github.com/db-migrate/mysql
* PostgreSQL (https://github.com/brianc/node-postgres)
https://github.com/db-migrate/pg
* sqlite3 (https://github.com/developmentseed/node-sqlite3)
https://github.com/db-migrate/sqlite
* Mongodb (https://github.com/mongodb/node-mongodb-native)
https://github.com/db-migrate/mongodb

## Resources and usage instructions

Please follow the link below, for usage instructions examples and the full
documentation of db-migrate.

Documentation: https://db-migrate.readthedocs.io/en/latest/

## License

(The MIT License)

Copyright (c) 2015 Tobias Gurtzick

Copyright (c) 2013 Jeff Kunkle

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> db-migrate-0.11.3.tgz: package/README.md <==
[![Backers on Open Collective](https://opencollective.com/node-db-migrate/backers/badge.svg)](#backers) [![Sponsors on Open Collective](https://opencollective.com/node-db-migrate/sponsors/badge.svg)](#sponsors)
[![Build Status](https://travis-ci.org/db-migrate/node-db-migrate.svg?branch=master)](https://travis-ci.org/db-migrate/node-db-migrate)
[![Dependency Status](https://david-dm.org/db-migrate/node-db-migrate.svg)](https://david-dm.org/db-migrate/node-db-migrate)
[![devDependency Status](https://david-dm.org/db-migrate/node-db-migrate/dev-status.svg)](https://david-dm.org/db-migrate/node-db-migrate#info=devDependencies)
[![Documentation Status](https://readthedocs.org/projects/db-migrate/badge/?version=latest)](https://readthedocs.org/projects/db-migrate/?badge=latest)

# db-migrate

[![Join the chat at https://gitter.im/db-migrate/node-db-migrate](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/db-migrate/node-db-migrate?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

[![NPM](https://nodei.co/npm/db-migrate.png?downloads=true&downloadRank=true)](https://nodei.co/npm/db-migrate/)

Database migration framework for node.js

# Platinum sponsors

Support this project by becoming a sponsor. Your logo will show up here with a link to your website. [[Become a sponsor](https://opencollective.com/node-db-migrate#sponsor)] or reach out to magic+dbsponsorship@wizardtales.com.

# Usage

## Installation

    $ npm install -g db-migrate

DB-Migrate is now available to you via:

    $ db-migrate

### As local module

Want to use db-migrate as local module?

    $ npm install db-migrate

DB-Migrate is now available to you via:

    $ node node_modules/db-migrate/bin/db-migrate

## Officially Supported Databases

- Mysql (https://github.com/felixge/node-mysql)
  https://github.com/db-migrate/mysql
- PostgreSQL (https://github.com/brianc/node-postgres)
  https://github.com/db-migrate/pg
- sqlite3 (https://github.com/developmentseed/node-sqlite3)
  https://github.com/db-migrate/sqlite
- Mongodb (https://github.com/mongodb/node-mongodb-native)
  https://github.com/db-migrate/mongodb

## Resources and usage instructions

Please follow the link below, for usage instructions examples and the full
documentation of db-migrate.

Documentation: https://db-migrate.readthedocs.io/en/latest/

# Support db-migrate

## Backers

A big thank you to our backers. You're a tremendous and important help, to keep the project healthy! [[Become a backer](https://opencollective.com/node-db-migrate#backer)]

<a href="https://opencollective.com/node-db-migrate#backers" target="_blank"><img src="https://opencollective.com/node-db-migrate/backers.svg?width=890"></a>

## Sponsors

Support this project by becoming a sponsor. Your logo will show up here with a link to your website. [[Become a sponsor](https://opencollective.com/node-db-migrate#sponsor)] or reach out to magic+dbsponsorship@wizardtales.com.

## License

(The MIT License)

Copyright (c) 2015 Tobias Gurtzick

Copyright (c) 2013 Jeff Kunkle

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
